@@ -11,7 +11,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from tests import unittest, temporary_file, random_chars
+from tests import unittest, temporary_file, random_chars, ClientHTTPStubber
 import os
 import time
 from collections import defaultdict
@@ -433,7 +433,8 @@ class TestS3Objects(TestS3BaseWithBucket):
 
     def test_thread_safe_auth(self):
         self.auth_paths = []
-        self.session.register('before-sign', self.increment_auth)
+        emitter = self.session.get_component('event_emitter')
+        emitter.register_last('before-sign.s3', self.increment_auth)
         # This test depends on auth_path, which is only added in virtual host
         # style requests.
         config = Config(s3={'addressing_style': 'virtual'})
@@ -819,6 +820,7 @@ class TestS3SigV4Client(BaseS3ClientTest):
         super(TestS3SigV4Client, self).setUp()
         self.client = self.session.create_client(
             's3', self.region, config=Config(signature_version='s3v4'))
+        self.http_stubber = ClientHTTPStubber(self.client)
 
     def test_can_get_bucket_location(self):
         # Even though the bucket is in us-west-2, we should still be able to
@@ -832,19 +834,10 @@ class TestS3SigV4Client(BaseS3ClientTest):
 
     def test_request_retried_for_sigv4(self):
         body = six.BytesIO(b"Hello world!")
-
-        original_send = Endpoint._send
-        state = mock.Mock()
-        state.error_raised = False
-
-        def mock_endpoint_send(self, *args, **kwargs):
-            if not state.error_raised:
-                state.error_raised = True
-                raise ConnectionClosedError(endpoint_url='')
-            else:
-                return original_send(self, *args, **kwargs)
-        # TODO: fix with stubber / before send event
-        with mock.patch('botocore.endpoint.Endpoint._send', mock_endpoint_send):
+        exception = ConnectionClosedError(endpoint_url='')
+        self.http_stubber.responses.append(exception)
+        self.http_stubber.responses.append(None)
+        with self.http_stubber:
             response = self.client.put_object(Bucket=self.bucket_name,
                                               Key='foo.txt', Body=body)
             self.assert_status_code(response, 200)
